'use strict';

const upath = require('upath');
const defu2 = require('defu');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

const defu2__default = /*#__PURE__*/_interopDefaultLegacy(defu2);

function resolveRuntimePath(...args) {
  return upath.resolve(__dirname, "runtime", ...args);
}

const templates = [
  "framework7/routes.js",
  "framework7/components.js",
  "framework7/styles.less",
  "framework7/custom.less",
  "App.js",
  "components/nuxt.js",
  "layouts/default.vue",
  "router.js"
];

const config = {
  rtl: false,
  components: [
    "appbar",
    "dialog",
    "popup",
    "login-screen",
    "popover",
    "actions",
    "sheet",
    "toast",
    "preloader",
    "progressbar",
    "sortable",
    "swipeout",
    "accordion",
    "contacts-list",
    "virtual-list",
    "list-index",
    "timeline",
    "tabs",
    "panel",
    "card",
    "chip",
    "form",
    "input",
    "checkbox",
    "radio",
    "toggle",
    "range",
    "stepper",
    "smart-select",
    "grid",
    "calendar",
    "picker",
    "infinite-scroll",
    "pull-to-refresh",
    "lazy",
    "data-table",
    "fab",
    "searchbar",
    "messages",
    "messagebar",
    "swiper",
    "photo-browser",
    "notification",
    "autocomplete",
    "tooltip",
    "gauge",
    "skeleton",
    "menu",
    "color-picker",
    "treeview",
    "text-editor",
    "elevation",
    "typography",
    "vi"
  ],
  darkTheme: true,
  lightTheme: true,
  themes: [
    "ios",
    "md",
    "aurora"
  ],
  themeColor: "#007aff",
  colors: {
    red: "#ff3b30",
    green: "#4cd964",
    blue: "#2196f3",
    pink: "#ff2d55",
    yellow: "#ffcc00",
    orange: "#ff9500",
    purple: "#9c27b0",
    deeppurple: "#673ab7",
    lightblue: "#5ac8fa",
    teal: "#009688",
    lime: "#cddc39",
    deeporange: "#ff6b22",
    gray: "#8e8e93",
    white: "#ffffff",
    black: "#000000"
  }
};

const {themeColor, colors, themes, components} = config;
const defaults = {
  app: {
    theme: "auto"
  },
  main: {
    main: true,
    pushState: true
  },
  invertNav: true,
  disableContextMenu: true,
  disableSelect: true,
  rtl: false,
  themeColor,
  themes,
  lightTheme: true,
  darkTheme: true,
  colors,
  components,
  css: true,
  customCSS: true,
  f7Icons: true,
  mdIcons: true,
  mode: "history",
  routes: {}
};

function getOptions(_options) {
  const options = defu2__default['default']({...this.options.framework7, ..._options}, defaults);
  if (options.mode === "history") {
    options.main.pushStateSeparator = "";
  }
  if (options.disableContextMenu) {
    if (!options.app.touch) {
      options.app.touch = {};
    }
    options.app.touch.disableContextMenu = true;
  }
  options._components = normalizeComponents(options.components);
  if (options.f7Icons) {
    options.f7IconsSrc = upath.normalize(require.resolve("framework7-icons/css/framework7-icons.css"));
  }
  if (options.mdIcons) {
    options.mdIconsSrc = resolveRuntimePath("fonts/material-icons.css");
  }
  return options;
}
function normalizeComponents(components) {
  return components.map((name) => ({
    name,
    js: `framework7/components/${name}/${name}.js`,
    less: `~framework7/components/${name}/${name}.less`
  }));
}

const nuxt7 = (function nuxt7(options2) {
  this.nuxt.hook("build:before", () => {
    prepareBuild.call(this, options2);
  });
});
function prepareBuild(_options) {
  const options2 = getOptions.call(this, _options);
  this.options.mode = "spa";
  this.options.render.ssr = false;
  this.options.build.ssr = false;
  this.extendBuild((config) => {
    const MAX_SIZE = 2 * 1024 * 1024;
    Object.assign(config.performance, {
      maxEntrypointSize: MAX_SIZE,
      maxAssetSize: MAX_SIZE
    });
  });
  this.options.build.transpile.push(/framework7[\\/](?!less)(?!components\/swiper\/swiper-src\/less)/, "framework7-vue", "template7", "dom7");
  if (options2.themeColor) {
    if (!this.options.manifest) {
      this.options.manifest = {};
    }
    this.options.manifest.theme_color = options2.themeColor;
  }
  const {cacheGroups} = this.options.build.optimization.splitChunks;
  cacheGroups.framework7 = {
    test: /node_modules[\\/](framework7|framework7-vue|dom7|template7|ssr-window|path-to-regexp)[\\/]/,
    chunks: "all",
    priority: 10,
    name: "framework7"
  };
  this.addPlugin({
    src: resolveRuntimePath("framework7/plugin.js"),
    fileName: "framework7/plugin.js",
    options: options2
  });
  for (const template of templates) {
    this.addTemplate({
      src: resolveRuntimePath(template),
      fileName: template,
      options: options2
    });
  }
  if (!this.options.meta) {
    this.options.meta = {};
  }
  if (this.options.meta.nativeUI === void 0) {
    this.options.meta.nativeUI = true;
  }
}

module.exports = nuxt7;
